package com.kabronkline.jft.service;

import org.apache.commons.vfs2.FileSystemException;
import org.apache.commons.vfs2.FileSystemOptions;
import org.apache.commons.vfs2.auth.StaticUserAuthenticator;
import org.apache.commons.vfs2.impl.DefaultFileSystemConfigBuilder;
import org.apache.log4j.Logger;


public class FtpFileSystemService extends FileSystemService {
	private static final Logger log = Logger.getLogger(FtpFileSystemService.class);
	
	private static final int _defaultMaxConnections = 1;
	protected String username;
	protected String password;
	protected String hostName;
	
	public FtpFileSystemService(String hostName, String username, String password) {
		this(hostName, username, password, _defaultMaxConnections);
	}
	
	public FtpFileSystemService(String hostName, String username, String password, int maxConnections) {
		super(maxConnections);
		this.hostName = hostName;
		this.username = username;
		this.password = password;
	}
	
	@Override
	protected FileSystemOptions createFileSystemOptions() {
		StaticUserAuthenticator auth = 
			new StaticUserAuthenticator(null, username, password);
		FileSystemOptions fileSystemOptions = new FileSystemOptions();
		try {
			DefaultFileSystemConfigBuilder.getInstance().
			setUserAuthenticator(fileSystemOptions, auth);
		} catch (FileSystemException e) {
			log.error("Failed to set authentication options.", e);
		}
		return fileSystemOptions;
	}
	
	@Override
	protected String getFilePathURI(String filePathURI) {
		return "ftp://" + hostName + "/" + filePathURI;
	}
}
