package com.kabronkline.jft.transfer;

import org.apache.commons.vfs2.FileObject;
import org.apache.commons.vfs2.FileSystemException;
import org.apache.commons.vfs2.Selectors;
import org.apache.log4j.Logger;

import com.kabronkline.jft.exception.FileTransferException;

public class FileTransfer implements Comparable<FileTransfer> {
	private static final Logger log = Logger.getLogger(FileTransfer.class);
	private static final int _defaultPriority = 0;
	private FileObject sourceFile;
	private FileObject destinationFile;
	private int priority;

	public FileTransfer(FileObject sourceFile, FileObject destinationFile) {
		this(sourceFile, destinationFile, _defaultPriority);
	}
	
	public FileTransfer(FileObject sourceFile, FileObject destinationFile, int priority) {
		this.sourceFile = sourceFile;
		this.destinationFile = destinationFile;
		this.priority = priority;
	}
	
	public void transferFile() throws FileTransferException {
		try {
			destinationFile.copyFrom(sourceFile, Selectors.SELECT_SELF);
		} catch (FileSystemException e) {
			log.error("Failed to transfer file " + sourceFile.getName(), e);
			throw new FileTransferException(e);
		}
	}
	
	public FileObject getSourceFile() {
		return sourceFile;
	}

	public void setSourceFile(FileObject sourceFile) {
		this.sourceFile = sourceFile;
	}

	public FileObject getDestinationFile() {
		return destinationFile;
	}

	public void setDestinationFile(FileObject destinationFile) {
		this.destinationFile = destinationFile;
	}

	@Override
	public int compareTo(FileTransfer fileTransfer) {
		if (priority > fileTransfer.priority) return 1;
		else if (priority < fileTransfer.priority) return -1;
		else return 0;
	}
}
