package com.kabronkline.jft.service;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.vfs2.FileObject;
import org.junit.Before;
import org.junit.Test;
import org.mockftpserver.fake.FakeFtpServer;
import org.mockftpserver.fake.UserAccount;
import org.mockftpserver.fake.filesystem.DirectoryEntry;
import org.mockftpserver.fake.filesystem.FileSystem;
import org.mockftpserver.fake.filesystem.UnixFakeFileSystem;

import com.kabronkline.jft.exception.FileSystemServiceException;
import com.kabronkline.jft.service.FtpFileSystemService;
import com.kabronkline.jft.service.LocalFileSystemService;
import com.kabronkline.jft.transfer.FileTransfer;

public class FtpFileSystemServiceTest extends FileSystemServiceTest {

	private List<File> tempFiles;
	@Before
	public void setUp() throws IOException {
		this.tempFiles = createTempFiles(10, 1024 * 1000);
		
		FakeFtpServer fakeFtpServer = new FakeFtpServer();
		fakeFtpServer.addUserAccount(new UserAccount("user", "password", "/home/user"));

		FileSystem fileSystem = new UnixFakeFileSystem();
		fileSystem.add(new DirectoryEntry("/"));
		fileSystem.add(new DirectoryEntry("/home"));
		fileSystem.add(new DirectoryEntry("/home/user"));
		fakeFtpServer.setFileSystem(fileSystem);

		fakeFtpServer.start();
	}

	@Test
	public void testUploadFilesSingleThread() {
		FtpFileSystemService ftpFS = new FtpFileSystemService("localhost", "user", "password", 1);
		LocalFileSystemService localFS = new LocalFileSystemService();
		assertNotNull(ftpFS);
		assertNotNull(localFS);
		try {
			long startTime = System.currentTimeMillis();
			for (File localTempFiles : tempFiles) {
				FileObject sourceFile = localFS.retrieveFile(localTempFiles.getPath());
				String destinationPathURI = "/" + sourceFile.getName().getBaseName();
				FileObject destinationFile = ftpFS.retrieveFile(destinationPathURI);
				ftpFS.transferFile(sourceFile, destinationFile);
			}
			long endTime = System.currentTimeMillis();
			System.out.println("Total time : " + (endTime - startTime));
		} catch (FileSystemServiceException e) {
			fail("Exception");
		}
	}

	@Test
	public void testUploadFilesMultiThread() {
		FtpFileSystemService ftpFS = new FtpFileSystemService("localhost", "user", "password", 3);
		LocalFileSystemService localFS = new LocalFileSystemService();
		assertTrue(ftpFS != null);
		assertTrue(localFS != null);
		try {
			List<FileTransfer> fileTransfers = new ArrayList<FileTransfer>();
			for (File localFile : tempFiles) {
				FileObject sourceFile = localFS.retrieveFile(localFile.getPath());
				String destinationPathURI = "/" + sourceFile.getName().getBaseName();
				FileObject destinationFile = ftpFS.retrieveFile(destinationPathURI);
				fileTransfers.add(new FileTransfer(sourceFile, destinationFile));
			}
			long startTime = System.currentTimeMillis();
			ftpFS.transferFiles(fileTransfers);
			long endTime = System.currentTimeMillis();
			System.out.println("Total time : " + (endTime - startTime));
		} catch (FileSystemServiceException e) {
			fail("Exception");
		}
	}
}
